@@ -6,9 +6,9 @@ setupF <- function(fit, xvar, call.env) {
     CALL <- fit$call
     ENV <- environment(fit$terms)
   }
-  if ("data" %in% names(fit)) {
+  if ("data" %in% names(fit) && is.data.frame(fit$data)) {
     Data <- fit$data
-    env <- NULL    
+    env <- NULL
   } else if (is.null(CALL$data)) {
     env <- NULL
     Data <- NULL
@@ -31,12 +31,12 @@ setupF <- function(fit, xvar, call.env) {
     s <- CALL$subset
     subset <- eval(substitute(s), Data, env)
     f <- f[which(subset==TRUE),]
-  } 
+  }
   suppressWarnings(f <- f[!apply(is.na(f), 1, any),])
 
   ## Handle some variable type issues
   needsUpdate <- FALSE
-  if (any(sapply(model.frame(fit),class)=="character")) needsUpdate <- TRUE
+  if (any(sapply(model.frame(fit, data=Data),class)=="character")) needsUpdate <- TRUE
   if (any(sapply(f,class)=="logical")) {
     needsUpdate <- TRUE
     for (j in 1:ncol(f)) if (class(f[,j])[1]=="logical") f[,j] <- as.numeric(f[,j])
@@ -44,7 +44,7 @@ setupF <- function(fit, xvar, call.env) {
   for (j in 1:ncol(f)) if (class(f[,j])[1]=="factor") f[,j] <- droplevels(f[,j])
   inModel <- sapply(names(f), grepl, x=as.character(formula(fit)[3]), fixed=TRUE)
   if (missing(xvar)) xvar <- names(f)[which(inModel)]
-  if (any(sapply(model.frame(fit),class)=="Surv")) needsUpdate <- TRUE
+  if (any(sapply(model.frame(fit, data=Data),class)=="Surv")) needsUpdate <- TRUE
   for (i in 1:length(xvar)){if (!is.element(xvar[i],names(f))) stop(paste(xvar[i],"not in model"))}
   attr(f, "needsUpdate") <- needsUpdate
   attr(f, "xvar") <- xvar
