@@ -8,13 +8,14 @@ visregPlot <- function(v, partial, rug, band, whitespace, line.par, fill.par, po
   upr <- v$fit$visregUpr
   xlim <- if (is.factor(xx)) c(0,1) else range(xx)
   ylab <- if (is.null(v$meta$yName)) paste("f(", v$meta$x, ")", sep="") else v$meta$yName
-  if (partial) {
+  if (partial && sum(!is.na(y))>0) {
     ylim <- range(c(y, lwr, upr), na.rm=TRUE)
   } else if (band) {
-    ylim <- range(c(lwr, upr), na.rm=TRUE)
+    ylim <- range(c(yy, lwr, upr), na.rm=TRUE)
   } else {
     ylim <- range(yy)
   }
+  if (partial && sum(!is.na(y))==0) warning(paste0("The generic function residuals() is not set up for this type of model object.  To plot partial residuals, you will need to define your own residuals.", v$meta$class[1], " function."))
   plot.args <- list(x=1, y=1, ylim=ylim, xlab=v$meta$x, ylab=ylab, type="n", xlim=xlim, xaxt=ifelse(is.factor(xx),'n','s'), las=1)
   new.args <- list(...)
   if (length(new.args)) plot.args[names(new.args)] <- new.args
@@ -28,7 +29,7 @@ visregPlot <- function(v, partial, rug, band, whitespace, line.par, fill.par, po
     if (band) {
       fill.args <- list(x=c(xx,rev(xx)), y=c(lwr,rev(upr)), col="gray85", border=F)
       if (length(fill.par)) fill.args[names(fill.par)] <- fill.par
-      do.call("polygon", fill.args)          
+      do.call("polygon", fill.args)
     }
     if (partial) {
       points.args <- list(x=x, y=y, pch=19, cex=0.4, col="gray50")
